Hero 是一个渐进式的 Agent 框架，能够帮助你快速构建和部署 Agent 应用。

Hero 提供了一种任务反馈循环机制，使得 Agent 具备了完善的反馈反思，自我纠错、自我提升机制。通过 Hero 创建的智能体，会根据任务的执行情况，不断调整自己的行为，反复迭代，最终完成任务。

框架将 Agent 的常见概念如 模型、任务、工具、记忆 等进行了封装和抽象，你可以深度定制相关模块，最大限度的发挥 Agent 的潜力。同时，我们将 Hero-Core 的架构设计的足够简单和渐进式，开发者可以直接上手使用。